@@ -3,7 +3,6 @@ from typing import Callable
 import pytest
 from eth_tester.exceptions import TransactionFailed
 from eth_typing.evm import HexAddress
-from web3 import Web3
 from web3.contract import Contract
 
 from raiden_contracts.constants import (
@@ -18,7 +17,6 @@ from raiden_contracts.tests.utils.constants import DEPLOYER_ADDRESS, UINT256_MAX
 
 
 def test_register_three_but_not_four(
-    web3: Web3,
     get_token_network_registry: Callable,
     secret_registry_contract: Contract,
     custom_token_factory: Callable,
@@ -28,7 +26,6 @@ def test_register_three_but_not_four(
     """Check that TokenNetworkRegistry observes the max number of tokens"""
     token_network_registry = get_token_network_registry(
         _secret_registry_address=secret_registry_contract.address,
-        _chain_id=web3.eth.chain_id,
         _settlement_timeout_min=TEST_SETTLE_TIMEOUT_MIN,
         _settlement_timeout_max=TEST_SETTLE_TIMEOUT_MAX,
         _max_token_networks=3,
